@@ -97,7 +97,7 @@
 .checkURLAvailable <- function(url) {
   toCheck <- try({httr::http_error(url)}, silent = TRUE)
   if (inherits(toCheck, "try-error") || toCheck) {
-    warning("No internet connection or data source broken.")
+    warning("The data source is temporarily unvailable. Please try it again later or contact the maintainer(s) to solve this issue.")
     rlang::interrupt()
   }
 }
